@@ -23,8 +23,24 @@ __all__ = ("StatusType", "SuiteRunStatusType")
 
 
 StatusType = Literal[
-    "CANCELED", "ERROR", "FAIL", "PASS", "PASS_WITH_WARNINGS", "PENDING", "RUNNING"
+    "CANCELED",
+    "ERROR",
+    "FAIL",
+    "PASS",
+    "PASS_WITH_WARNINGS",
+    "PENDING",
+    "RUNNING",
+    "STOPPED",
+    "STOPPING",
 ]
 SuiteRunStatusType = Literal[
-    "CANCELED", "ERROR", "FAIL", "PASS", "PASS_WITH_WARNINGS", "PENDING", "RUNNING"
+    "CANCELED",
+    "ERROR",
+    "FAIL",
+    "PASS",
+    "PASS_WITH_WARNINGS",
+    "PENDING",
+    "RUNNING",
+    "STOPPED",
+    "STOPPING",
 ]
