@@ -33,16 +33,12 @@ __all__ = (
     "ListSuiteDefinitionsResponseTypeDef",
     "ListSuiteRunsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "ListTestCasesResponseTypeDef",
     "StartSuiteRunResponseTypeDef",
     "SuiteDefinitionConfigurationTypeDef",
     "SuiteDefinitionInformationTypeDef",
     "SuiteRunConfigurationTypeDef",
     "SuiteRunInformationTypeDef",
-    "TestCaseCategoryTypeDef",
-    "TestCaseDefinitionTypeDef",
     "TestCaseRunTypeDef",
-    "TestCaseTypeDef",
     "TestResultTypeDef",
     "UpdateSuiteDefinitionResponseTypeDef",
 )
@@ -144,17 +140,6 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     total=False,
 )
 
-ListTestCasesResponseTypeDef = TypedDict(
-    "ListTestCasesResponseTypeDef",
-    {
-        "categories": List["TestCaseCategoryTypeDef"],
-        "rootGroupConfiguration": Dict[str, str],
-        "groupConfiguration": Dict[str, str],
-        "nextToken": str,
-    },
-    total=False,
-)
-
 StartSuiteRunResponseTypeDef = TypedDict(
     "StartSuiteRunResponseTypeDef",
     {
@@ -193,7 +178,6 @@ SuiteRunConfigurationTypeDef = TypedDict(
     "SuiteRunConfigurationTypeDef",
     {
         "primaryDevice": "DeviceUnderTestTypeDef",
-        "secondaryDevice": "DeviceUnderTestTypeDef",
         "selectedTestList": List[str],
     },
     total=False,
@@ -216,24 +200,6 @@ SuiteRunInformationTypeDef = TypedDict(
     total=False,
 )
 
-TestCaseCategoryTypeDef = TypedDict(
-    "TestCaseCategoryTypeDef",
-    {
-        "name": str,
-        "tests": List["TestCaseTypeDef"],
-    },
-    total=False,
-)
-
-TestCaseDefinitionTypeDef = TypedDict(
-    "TestCaseDefinitionTypeDef",
-    {
-        "id": str,
-        "testCaseVersion": str,
-    },
-    total=False,
-)
-
 TestCaseRunTypeDef = TypedDict(
     "TestCaseRunTypeDef",
     {
@@ -250,16 +216,6 @@ TestCaseRunTypeDef = TypedDict(
     total=False,
 )
 
-TestCaseTypeDef = TypedDict(
-    "TestCaseTypeDef",
-    {
-        "name": str,
-        "configuration": Dict[str, str],
-        "test": "TestCaseDefinitionTypeDef",
-    },
-    total=False,
-)
-
 TestResultTypeDef = TypedDict(
     "TestResultTypeDef",
     {
